cq-studio documentation — cq-studio 0.8 documentation

# cq-studio documentation

## About `cq-studio`

`cq-studio` is a hot-reloading server for to view CadQuery 3D models interactively while you edit your code.

CadQuery is used to programmatically design models, with Python code.

`cq-studio` uses the YACV-server viewer, which renders your models in your web browser, with an advanced set of controls and features.

`cq-studio` allows you to edit your model file(s) and packages or modules which they import, and automatically re-render the models in your browser whenever the changes are saved to disk.

Contents:

- Resources
  - Website / documentation
  - Repository
  - Mailing List
  - Contact
- Installation
  - Short version
  - Details
- Use
  - Short version
  - Details
  - Memory/CPU Issues
  - Viewer Interface
- Example Project
- Additional Functionality
  - Rendering Colours
  - Symbolic Constants
  - Size / CylinderSize Classes
  - Trigonometric Classes and Functions
  - Unit Conversion
- FAQ
  - Why use this instead of just using the YACV / yacv-server package?
  - This documentation is pretty generic looking, isn’t it?
  - Calling this “cq-studio” - that’s kind of pretentious, isn’t it?
  - Help! Or, I found a bug! Or, I Need a Feature!